@@ -20,6 +20,15 @@ AUTHFAILURE = 'AuthFailure'
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
+# 按key回档未开启
+FAILEDOPERATION_FLASHBACKBYKEYNOTOPEN = 'FailedOperation.FlashbackByKeyNotOpen'
+
+# 内核响应超时。
+FAILEDOPERATION_KERNELRESPONSETIMEOUT = 'FailedOperation.KernelResponseTimeout'
+
+# 当前实例已开启外网访问。
+FAILEDOPERATION_NOTALLOWMODIFYADDRAFTEROPENWANSERVICE = 'FailedOperation.NotAllowModifyAddrAfterOpenWanService'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -29,6 +38,9 @@ INTERNALERROR_CHECKAPPIDFAILED = 'InternalError.CheckAppIdFailed'
 # 实例查询失败。
 INTERNALERROR_FINDINSTANCEFAILED = 'InternalError.FindInstanceFailed'
 
+# password与原先记录的password不同。
+INTERNALERROR_PASSWORDERROR = 'InternalError.PasswordError'
+
 # 参数错误。
 INVALIDPARAMETER = 'InvalidParameter'
 
@@ -38,7 +50,10 @@ INVALIDPARAMETER_CURRENTINSTANCENOTSUPPORTMODIFYPARAMS = 'InvalidParameter.Curre
 # 无效Vip信息。
 INVALIDPARAMETER_INVALIDVIP = 'InvalidParameter.InvalidVip'
 
-# 当前子帐号无权执行该操作。
+# 接口参数为空。
+INVALIDPARAMETER_PARAMETERSNIL = 'InvalidParameter.ParametersNil'
+
+# 当前子账号无权执行该操作。
 INVALIDPARAMETER_PERMISSIONDENIED = 'InvalidParameter.PermissionDenied'
 
 # 可用区已关闭售卖。
@@ -140,6 +155,9 @@ INVALIDPARAMETERVALUE_REPLICASETNUMERROR = 'InvalidParameterValue.ReplicaSetNumE
 # 从节点数错误。
 INVALIDPARAMETERVALUE_SECONDARYNUMERROR = 'InvalidParameterValue.SecondaryNumError'
 
+# 安全组ID无效。
+INVALIDPARAMETERVALUE_SECURITYGROUPID = 'InvalidParameterValue.SecurityGroupId'
+
 # 设置的磁盘大小不得低于已用磁盘的1.2倍。
 INVALIDPARAMETERVALUE_SETDISKLESSTHANUSED = 'InvalidParameterValue.SetDiskLessThanUsed'
 
@@ -176,5 +194,8 @@ RESOURCENOTFOUND = 'ResourceNotFound'
 # 操作不支持。
 UNSUPPORTEDOPERATION = 'UnsupportedOperation'
 
+# 内核版本不支持。
+UNSUPPORTEDOPERATION_KERNELVERSIONNOTSUPPORT = 'UnsupportedOperation.KernelVersionNotSupport'
+
 # 当前版本不支持该操作。
 UNSUPPORTEDOPERATION_VERSIONNOTSUPPORT = 'UnsupportedOperation.VersionNotSupport'
