@@ -146,6 +146,9 @@ FAILEDOPERATION_NOTALLOW = 'FailedOperation.NotAllow'
 # 该Notebook实例不支持保存镜像，如果您使用的是自定义镜像请重启Notebook实例后再执行保存操作
 FAILEDOPERATION_NOTSUPPORTEDTOCREATEIMAGE = 'FailedOperation.NotSupportedToCreateImage'
 
+# 未找到Notebook实例相关容器，无法生成访问地址。
+FAILEDOPERATION_PODIPNOTFOUND = 'FailedOperation.PodIpNotFound'
+
 # 请求正在处理中，请稍后再试。
 FAILEDOPERATION_PROCESSING = 'FailedOperation.Processing'
 
@@ -242,6 +245,9 @@ INTERNALERROR_QUERYBINDINGTAGSFAILED = 'InternalError.QueryBindingTagsFailed'
 # 获取HDFS存储信息失败。
 INTERNALERROR_QUERYHDFSINFOFAILED = 'InternalError.QueryHDFSInfoFailed'
 
+# 询价失败
+INTERNALERROR_QUERYPRICEFAILED = 'InternalError.QueryPriceFailed'
+
 # 查询预付费资源组详情失败。
 INTERNALERROR_QUERYRESOURCEGROUPFAILED = 'InternalError.QueryResourceGroupFailed'
 
@@ -254,6 +260,9 @@ INTERNALERROR_QUERYRESOURCESPECFAILED = 'InternalError.QueryResourceSpecFailed'
 # 查询子网信息失败。
 INTERNALERROR_QUERYSUBNETINFOFAILED = 'InternalError.QuerySubnetInfoFailed'
 
+# 查询用户临时秘钥失败
+INTERNALERROR_QUERYUSERTMPCREDENTIALFAILED = 'InternalError.QueryUserTMPCredentialFailed'
+
 # 停止任务失败。
 INTERNALERROR_STOPJOBINSTANCEFAILED = 'InternalError.StopJobInstanceFailed'
 
@@ -284,9 +293,18 @@ INVALIDPARAMETER_VALIDATEERROR = 'InvalidParameter.ValidateError'
 # 参数取值错误。
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
+# 当前任务选择了平台CFS的内置代码，且未正确配置/opt/ml/output/data输出路径，任务无法提交
+INVALIDPARAMETERVALUE_AIMARKETOUTPUTCONFIGEMPTY = 'InvalidParameterValue.AIMarketOutputConfigEmpty'
+
 # AI市场公共算法版本Id不存在
 INVALIDPARAMETERVALUE_AIMARKETPUBLICALGOVERSIONNOTEXIST = 'InvalidParameterValue.AIMarketPublicAlgoVersionNotExist'
 
+# 无效的自动重启次数
+INVALIDPARAMETERVALUE_BACKOFFLIMITILLEGAL = 'InvalidParameterValue.BackOffLimitIllegal'
+
+# 该任务不支持自动重启
+INVALIDPARAMETERVALUE_BACKOFFLIMITNOTSUPPORT = 'InvalidParameterValue.BackOffLimitNotSupport'
+
 # 名称不合法。
 INVALIDPARAMETERVALUE_BADNAME = 'InvalidParameterValue.BadName'
 
@@ -323,6 +341,9 @@ INVALIDPARAMETERVALUE_DCDATASETTYPE = 'InvalidParameterValue.DCDatasetType'
 # 不支持的过滤参数。
 INVALIDPARAMETERVALUE_DCFILTERVALUES = 'InvalidParameterValue.DCFilterValues'
 
+# 数据集不存在
+INVALIDPARAMETERVALUE_DATASETNOTEXIST = 'InvalidParameterValue.DatasetNotExist'
+
 # 数据集数量超过限制。
 INVALIDPARAMETERVALUE_DATASETNUMLIMITEXCEEDED = 'InvalidParameterValue.DatasetNumLimitExceeded'
 
@@ -335,6 +356,15 @@ INVALIDPARAMETERVALUE_FRAMEWORKVERSIONNOTSUPPORT = 'InvalidParameterValue.Framew
 # 获取CFS的挂载IP失败
 INVALIDPARAMETERVALUE_GETCFSMOUNTIPFAILED = 'InvalidParameterValue.GetCFSMountIPFailed'
 
+# 获取GooseFS实例失败
+INVALIDPARAMETERVALUE_GETGOOSEFSFAILED = 'InvalidParameterValue.GetGooseFSFailed'
+
+# GooseFS的配置不能为空
+INVALIDPARAMETERVALUE_GOOSEFSCONFIGCANNOTEMPTY = 'InvalidParameterValue.GooseFSConfigCannotEmpty'
+
+# 所选的GooseFS实例不存在
+INVALIDPARAMETERVALUE_GOOSEFSNOTEXIST = 'InvalidParameterValue.GooseFSNotExist'
+
 # 训练任务镜像不存在。
 INVALIDPARAMETERVALUE_IMAGENOTFOUND = 'InvalidParameterValue.ImageNotFound'
 
@@ -353,12 +383,21 @@ INVALIDPARAMETERVALUE_NOTALLOW = 'InvalidParameterValue.NotAllow'
 # 裸金属资源组不支持创建免费存储的Notebook
 INVALIDPARAMETERVALUE_NOTALLOWEDTOCREATEFREEVOLUMENOTEBOOKWITHBAREMETALRESOURCEGROUP = 'InvalidParameterValue.NotAllowedToCreateFreeVolumeNotebookWithBareMetalResourceGroup'
 
+# 纳管资源组不支持cbs存储，请使用CFS
+INVALIDPARAMETERVALUE_NOTALLOWEDTOCREATEFREEVOLUMENOTEBOOKWITHSWRESOURCEGROUP = 'InvalidParameterValue.NotAllowedToCreateFreeVolumeNotebookWithSWResourceGroup'
+
 # 裸金属资源组不支持创建Notebook
 INVALIDPARAMETERVALUE_NOTALLOWEDTOCREATENOTEBOOKWITHBAREMETALRESOURCEGROUP = 'InvalidParameterValue.NotAllowedToCreateNotebookWithBareMetalResourceGroup'
 
 # 分页查询limit超出限制
 INVALIDPARAMETERVALUE_PAGELIMITEXCEEDED = 'InvalidParameterValue.PageLimitExceeded'
 
+# 参数长度超过限制
+INVALIDPARAMETERVALUE_PARAMLENGTHEXCEEDLIMIT = 'InvalidParameterValue.ParamLengthExceedLimit'
+
+# 查询vpc信息失败
+INVALIDPARAMETERVALUE_QUERYVPCINFOFAILED = 'InvalidParameterValue.QueryVPCInfoFailed'
+
 # RDMA配置不合法
 INVALIDPARAMETERVALUE_RDMACONFIGILLEGAL = 'InvalidParameterValue.RDMAConfigIllegal'
 
@@ -368,12 +407,18 @@ INVALIDPARAMETERVALUE_RESOURCECONFIGILLEGAL = 'InvalidParameterValue.ResourceCon
 # 子网不存在。
 INVALIDPARAMETERVALUE_SUBNETNOTFOUND = 'InvalidParameterValue.SubnetNotFound'
 
+# 创建精调任务失败，请按照模版推荐资源进行配置。
+INVALIDPARAMETERVALUE_TAIJIRESOURCECONFIGILLEGAL = 'InvalidParameterValue.TAIJIResourceConfigIllegal'
+
 # 未找到当前日志主题。
 INVALIDPARAMETERVALUE_TOPICNOTFOUND = 'InvalidParameterValue.TopicNotFound'
 
 # 裸金属类型资源组不支持配置输入数据
 INVALIDPARAMETERVALUE_UNSUPPORTEDDATACONFIG = 'InvalidParameterValue.UnsupportedDataConfig'
 
+# 不支持使用GooseFS实例
+INVALIDPARAMETERVALUE_UNSUPPORTEDGOOSEFSCONFIG = 'InvalidParameterValue.UnsupportedGooseFSConfig'
+
 # Notebook卷大小只能增加，如需减小容量请重新创建实例。
 INVALIDPARAMETERVALUE_VOLUMESHRINKNOTALLOW = 'InvalidParameterValue.VolumeShrinkNotAllow'
 
@@ -395,6 +440,9 @@ OPERATIONDENIED_BILLINGEXCEPTION = 'OperationDenied.BillingException'
 # 按量计费资源售罄。
 OPERATIONDENIED_BILLINGSTATUSRESOURCEINSUFFICIENT = 'OperationDenied.BillingStatusResourceInsufficient'
 
+# vpc 和 子网 禁止修改
+OPERATIONDENIED_FORBIDMODIFYVPCANDSUBNET = 'OperationDenied.ForbidModifyVpcAndSubnet'
+
 # IP不合法。
 OPERATIONDENIED_IPILLEGAL = 'OperationDenied.IpIllegal'
 
@@ -416,6 +464,9 @@ OPERATIONDENIED_RESOURCEGROUPINSUFFICIENT = 'OperationDenied.ResourceGroupInsuff
 # 子网不合法。
 OPERATIONDENIED_SUBNETILLEGAL = 'OperationDenied.SubnetIllegal'
 
+# 太极应用组存量资源不足，不满足训练要求
+OPERATIONDENIED_TAIJIAPPLICATIONGROUPINSUFFICIENT = 'OperationDenied.TAIJIApplicationGroupInsufficient'
+
 # 白名单免费配额不足。
 OPERATIONDENIED_WHITELISTQUOTAEXCEED = 'OperationDenied.WhitelistQuotaExceed'
 
